Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Enviper ¶
Enviper is a wrapper struct for viper, that makes it possible to unmarshal config to struct considering environment variables
func (*Enviper) Unmarshal ¶
func (e *Enviper) Unmarshal(rawVal interface{}, opts ...viper.DecoderConfigOption) error
Unmarshal unmarshals the config into a Struct just like viper does. The difference between enviper and viper is in automatic overriding data from file by data from env variables
func (*Enviper) WithTagName ¶
WithTagName sets custom tag name to be used instead of default `mapstructure`
Click to show internal directories.
Click to hide internal directories.